==> libreoffice-fresh-sdk-24.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow =
[
    [ "RowInteropGrabBag", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae3ea6dbb58e8d978c6ab7a35b51aa8b3", null ],
    [ "TableColumnSeparators", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a3102ad4ffa5d13abd7cc43ec344a35bc", null ],
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "BackColor", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a5e27a55a4308a6862dec0a580fa3d201", null ],
    [ "BackGraphic", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a693b9e884e9ada31d9657de3f9476eef", null ],
    [ "BackGraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ad6e49dda9aa792372fdd52385d04aa4f", null ],
    [ "BackGraphicLocation", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a229455fd0417732944f850139fdf96d5", null ],
    [ "BackGraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a6b97d77257452a59e2cb997be9e04eca", null ],
    [ "BackTransparent", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae5bf2cbe8fd11ee5aa797178a0f2c31d", null ],
    [ "HasTextChangesOnly", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#aae144a800140779c1fc11cbf3fdf6fa0", null ],
    [ "Height", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae419f6e85ca63aca1b00db3e46953e83", null ],
    [ "IsAutoHeight", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a8f93f8b2cd381fd7200649fa1edc2abd", null ],
    [ "IsSplitAllowed", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ad80a162981f709852a0e193e1c4e972c", null ]
];

==> libreoffice-fresh-sdk-25.8.3-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow =
[
    [ "RowInteropGrabBag", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae3ea6dbb58e8d978c6ab7a35b51aa8b3", null ],
    [ "TableColumnSeparators", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a3102ad4ffa5d13abd7cc43ec344a35bc", null ],
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "BackColor", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a5e27a55a4308a6862dec0a580fa3d201", null ],
    [ "BackGraphic", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a693b9e884e9ada31d9657de3f9476eef", null ],
    [ "BackGraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ad6e49dda9aa792372fdd52385d04aa4f", null ],
    [ "BackGraphicLocation", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a229455fd0417732944f850139fdf96d5", null ],
    [ "BackGraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a6b97d77257452a59e2cb997be9e04eca", null ],
    [ "BackTransparent", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae5bf2cbe8fd11ee5aa797178a0f2c31d", null ],
    [ "HasTextChangesOnly", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#aae144a800140779c1fc11cbf3fdf6fa0", null ],
    [ "Height", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ae419f6e85ca63aca1b00db3e46953e83", null ],
    [ "IsAutoHeight", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#a8f93f8b2cd381fd7200649fa1edc2abd", null ],
    [ "IsSplitAllowed", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html#ad80a162981f709852a0e193e1c4e972c", null ]
];
